local L = AceLibrary("AceLocale-2.2"):new("Depot")

Depot = AceLibrary("AceAddon-2.0"):new(
	"FuBarPlugin-2.0",
	"AceConsole-2.0",
	"AceEvent-2.0",
	"AceDB-2.0"
)

-- ---------------------------------------------------------------------------------
-- options
-- ---------------------------------------------------------------------------------
local options = { 
    type='group',
    args = {
		height = {
            type = 'range', min = 50, max = 300, step = 1,
            name = L["Height"],
            desc = L["Height of the bottom bar in pixels"],
           	usage = L["Enter value"],
            get = "GetHeight",
            set = "SetHeight",
        },
        width = {
            type = 'range', min = 50, max = 1800, step = 1,
            name = L["Width"],
            desc = L["Width of the bottom bar in pixels"],
           	usage = L["Enter value"],
            get = "GetWidth",
            set = "SetWidth",
        },
	},
}

-- ---------------------------------------------------------------------------------
-- registrations
-- ---------------------------------------------------------------------------------
Depot:RegisterChatCommand({"/depot", "/dt"}, options)
Depot:RegisterDB("DepotDB", "DepotCharDB")
Depot:RegisterDefaults(
		"profile", 
		{
    		height = 125,
    		width = 1800,
		} 
)

-- ---------------------------------------------------------------------------------
-- FuBar
-- ---------------------------------------------------------------------------------
Depot.OnMenuRequest = options
Depot.hasIcon = "Interface\\AddOns\\Depot\\icon"
Depot.hasNoColor = true
Depot.independentProfile = true
Depot.hideWithoutStandby = true


-- ---------------------------------------------------------------------------------
-- functions
-- ---------------------------------------------------------------------------------
function Depot:GetHeight()
	return self.db.profile.height
end

function Depot:SetHeight(newValue)
	self.db.profile.height = newValue
	self.depotframe:SetHeight(self.db.profile.height)
end

function Depot:GetWidth()
	return self.db.profile.width
end

function Depot:SetWidth(newValue)
	self.db.profile.width = newValue
	self.depotframe:SetWidth(self.db.profile.width)
end

function Depot:OnInitialize()
	self:CreateDepotFrame(frame)
	self:Print(L["Depot loaded successfully!"])
end

function Depot:OnEnable()
    self.depotframe:Show()
end

function Depot:OnDisable()
    self.depotframe:Hide()
end

function Depot:OnProfileEnable()
	self.depotframe:SetHeight(self.db.profile.height)
	self.depotframe:SetWidth(self.db.profile.width)
	self.depotframegradient:SetWidth(self.db.profile.width - 10)
	self.depotframegradient:SetHeight(self.db.profile.height)
end

function Depot:CreateDepotFrame(frame)
	local frame = CreateFrame("Frame", DepotFrame, UIParent)
	
	frame:SetWidth(self.db.profile.width)
	frame:SetHeight(self.db.profile.height)
	frame:SetBackdrop({
		bgFile = "Interface\\ChatFrame\\ChatFrameBackground", tile = true, tileSize = 16,
		edgeFile = "Interface\\Tooltips\\UI-Tooltip-Border", edgeSize = 16,
		insets = {left = 4, right = 4, top = 4, bottom = 4},
	})
	frame:SetBackdropBorderColor(0, 0, 0, 1)
	frame:SetBackdropColor(0, 0, 0, 1)
	frame:EnableMouse(false)
	frame:SetMovable(false)
	frame:ClearAllPoints()
	frame:SetPoint("BOTTOM", UIParent, "BOTTOM", 0, -10)
	frame:SetFrameStrata("BACKGROUND")
	
	frame.gradient = frame:CreateTexture(nil, "BORDER")
--	frame.gradient:SetWidth(GetScreenWidth() + 150)
--	frame.gradient:SetHeight(50)
	frame.gradient:SetWidth(self.db.profile.width - 10)
	frame.gradient:SetHeight(self.db.profile.height)
	frame.gradient:SetTexture("Interface\\ChatFrame\\ChatFrameBackground")
	frame.gradient:SetPoint("TOP", frame, "TOP", 0, -4)
	frame.gradient:SetBlendMode("ADD")
	frame.gradient:SetGradientAlpha("VERTICAL", .1, .1, .1, 0, .25, .25, .25, .5)
	
	self.depotframe = frame
	self.depotframegradient = frame.gradient
end
